# LauncherStatus

Object describing the status of a Launcher

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**application_services** | [**[ApplicationService]**](ApplicationService.md) | Application services utilized by this Launcher. | [optional] 
**file_shares** | [**[FileShareService]**](FileShareService.md) | FileShare services utilized by this Launcher | [optional] 
**alternate_mode_status** | [**AlternateModeStatus**](AlternateModeStatus.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


